@@ -1,4 +1,4 @@
-#%% begin initialize heimdal-1.0-i386
+#%% begin initialize heimdal-1.3
 export PATH=/bin:/usr/bin:/sbin:/usr/sbin
 
 if [ -r /tmp/SeTT_PX ]; then
@@ -63,69 +63,77 @@ fi
 #%% end
 
 
-( cd usr/heimdal/lib ; rm -rf libeditline.so )
-( cd usr/heimdal/lib ; ln -sf libeditline.so.0.0.0 libeditline.so )
-( cd usr/heimdal/lib ; rm -rf libkadm5clnt.so )
-( cd usr/heimdal/lib ; ln -sf libkadm5clnt.so.7.0.1 libkadm5clnt.so )
-( cd usr/heimdal/lib ; rm -rf libasn1.so )
-( cd usr/heimdal/lib ; ln -sf libasn1.so.8.0.0 libasn1.so )
-( cd usr/heimdal/lib ; rm -rf libwind.so.0 )
-( cd usr/heimdal/lib ; ln -sf libwind.so.0.0.0 libwind.so.0 )
-( cd usr/heimdal/lib ; rm -rf libotp.so )
-( cd usr/heimdal/lib ; ln -sf libotp.so.0.1.5 libotp.so )
-( cd usr/heimdal/lib ; rm -rf libroken.so )
-( cd usr/heimdal/lib ; ln -sf libroken.so.18.1.0 libroken.so )
-( cd usr/heimdal/lib ; rm -rf libheimntlm.so )
-( cd usr/heimdal/lib ; ln -sf libheimntlm.so.0.1.0 libheimntlm.so )
-( cd usr/heimdal/lib ; rm -rf libkadm5srv.so.8 )
-( cd usr/heimdal/lib ; ln -sf libkadm5srv.so.8.0.1 libkadm5srv.so.8 )
 ( cd usr/heimdal/lib ; rm -rf libroken.so.18 )
 ( cd usr/heimdal/lib ; ln -sf libroken.so.18.1.0 libroken.so.18 )
-( cd usr/heimdal/lib ; rm -rf windc.so )
-( cd usr/heimdal/lib ; ln -sf windc.so.0.0.0 windc.so )
-( cd usr/heimdal/lib ; rm -rf libhdb.so.9 )
-( cd usr/heimdal/lib ; ln -sf libhdb.so.9.2.0 libhdb.so.9 )
-( cd usr/heimdal/lib ; rm -rf windc.so.0 )
-( cd usr/heimdal/lib ; ln -sf windc.so.0.0.0 windc.so.0 )
-( cd usr/heimdal/lib ; rm -rf libhdb.so )
-( cd usr/heimdal/lib ; ln -sf libhdb.so.9.2.0 libhdb.so )
-( cd usr/heimdal/lib ; rm -rf libkdc.so.2 )
-( cd usr/heimdal/lib ; ln -sf libkdc.so.2.0.0 libkdc.so.2 )
-( cd usr/heimdal/lib ; rm -rf libsl.so.0 )
-( cd usr/heimdal/lib ; ln -sf libsl.so.0.2.1 libsl.so.0 )
-( cd usr/heimdal/lib ; rm -rf libgssapi.so )
-( cd usr/heimdal/lib ; ln -sf libgssapi.so.2.0.0 libgssapi.so )
-( cd usr/heimdal/lib ; rm -rf libkafs.so )
-( cd usr/heimdal/lib ; ln -sf libkafs.so.0.5.1 libkafs.so )
+( cd usr/heimdal/lib ; rm -rf libroken.so )
+( cd usr/heimdal/lib ; ln -sf libroken.so.18.1.0 libroken.so )
 ( cd usr/heimdal/lib ; rm -rf libeditline.so.0 )
 ( cd usr/heimdal/lib ; ln -sf libeditline.so.0.0.0 libeditline.so.0 )
-( cd usr/heimdal/lib ; rm -rf libkdc.so )
-( cd usr/heimdal/lib ; ln -sf libkdc.so.2.0.0 libkdc.so )
-( cd usr/heimdal/lib ; rm -rf libasn1.so.8 )
-( cd usr/heimdal/lib ; ln -sf libasn1.so.8.0.0 libasn1.so.8 )
-( cd usr/heimdal/lib ; rm -rf libheimntlm.so.0 )
-( cd usr/heimdal/lib ; ln -sf libheimntlm.so.0.1.0 libheimntlm.so.0 )
+( cd usr/heimdal/lib ; rm -rf libeditline.so )
+( cd usr/heimdal/lib ; ln -sf libeditline.so.0.0.0 libeditline.so )
+( cd usr/heimdal/lib ; rm -rf libcom_err.so.1 )
+( cd usr/heimdal/lib ; ln -sf libcom_err.so.1.1.3 libcom_err.so.1 )
+( cd usr/heimdal/lib ; rm -rf libcom_err.so )
+( cd usr/heimdal/lib ; ln -sf libcom_err.so.1.1.3 libcom_err.so )
+( cd usr/heimdal/lib ; rm -rf libsl.so.0 )
+( cd usr/heimdal/lib ; ln -sf libsl.so.0.2.1 libsl.so.0 )
 ( cd usr/heimdal/lib ; rm -rf libsl.so )
 ( cd usr/heimdal/lib ; ln -sf libsl.so.0.2.1 libsl.so )
-( cd usr/heimdal/lib ; rm -rf libkrb5.so )
-( cd usr/heimdal/lib ; ln -sf libkrb5.so.25.0.0 libkrb5.so )
-( cd usr/heimdal/lib ; rm -rf libhx509.so )
-( cd usr/heimdal/lib ; ln -sf libhx509.so.4.0.0 libhx509.so )
-( cd usr/heimdal/lib ; rm -rf libkrb5.so.25 )
-( cd usr/heimdal/lib ; ln -sf libkrb5.so.25.0.0 libkrb5.so.25 )
-( cd usr/heimdal/lib ; rm -rf libhx509.so.4 )
-( cd usr/heimdal/lib ; ln -sf libhx509.so.4.0.0 libhx509.so.4 )
-( cd usr/heimdal/lib ; rm -rf libkadm5clnt.so.7 )
-( cd usr/heimdal/lib ; ln -sf libkadm5clnt.so.7.0.1 libkadm5clnt.so.7 )
-( cd usr/heimdal/lib ; rm -rf libkafs.so.0 )
-( cd usr/heimdal/lib ; ln -sf libkafs.so.0.5.1 libkafs.so.0 )
-( cd usr/heimdal/lib ; rm -rf libkadm5srv.so )
-( cd usr/heimdal/lib ; ln -sf libkadm5srv.so.8.0.1 libkadm5srv.so )
+( cd usr/heimdal/lib ; rm -rf libwind.so.0 )
+( cd usr/heimdal/lib ; ln -sf libwind.so.0.0.0 libwind.so.0 )
 ( cd usr/heimdal/lib ; rm -rf libwind.so )
 ( cd usr/heimdal/lib ; ln -sf libwind.so.0.0.0 libwind.so )
-( cd usr/heimdal/lib ; rm -rf libotp.so.0 )
-( cd usr/heimdal/lib ; ln -sf libotp.so.0.1.5 libotp.so.0 )
+( cd usr/heimdal/lib ; rm -rf libasn1.so.8 )
+( cd usr/heimdal/lib ; ln -sf libasn1.so.8.0.0 libasn1.so.8 )
+( cd usr/heimdal/lib ; rm -rf libasn1.so )
+( cd usr/heimdal/lib ; ln -sf libasn1.so.8.0.0 libasn1.so )
+( cd usr/heimdal/lib ; rm -rf libheimsqlite.so.0 )
+( cd usr/heimdal/lib ; ln -sf libheimsqlite.so.0.0.0 libheimsqlite.so.0 )
+( cd usr/heimdal/lib ; rm -rf libheimsqlite.so )
+( cd usr/heimdal/lib ; ln -sf libheimsqlite.so.0.0.0 libheimsqlite.so )
+( cd usr/heimdal/lib ; rm -rf libhx509.so.5 )
+( cd usr/heimdal/lib ; ln -sf libhx509.so.5.0.0 libhx509.so.5 )
+( cd usr/heimdal/lib ; rm -rf libhx509.so )
+( cd usr/heimdal/lib ; ln -sf libhx509.so.5.0.0 libhx509.so )
+( cd usr/heimdal/lib ; rm -rf libkrb5.so.26 )
+( cd usr/heimdal/lib ; ln -sf libkrb5.so.26.0.0 libkrb5.so.26 )
+( cd usr/heimdal/lib ; rm -rf libkrb5.so )
+( cd usr/heimdal/lib ; ln -sf libkrb5.so.26.0.0 libkrb5.so )
+( cd usr/heimdal/lib ; rm -rf libheimntlm.so.0 )
+( cd usr/heimdal/lib ; ln -sf libheimntlm.so.0.1.0 libheimntlm.so.0 )
+( cd usr/heimdal/lib ; rm -rf libheimntlm.so )
+( cd usr/heimdal/lib ; ln -sf libheimntlm.so.0.1.0 libheimntlm.so )
+( cd usr/heimdal/lib ; rm -rf libkafs.so.0 )
+( cd usr/heimdal/lib ; ln -sf libkafs.so.0.5.1 libkafs.so.0 )
+( cd usr/heimdal/lib ; rm -rf libkafs.so )
+( cd usr/heimdal/lib ; ln -sf libkafs.so.0.5.1 libkafs.so )
 ( cd usr/heimdal/lib ; rm -rf libgssapi.so.2 )
 ( cd usr/heimdal/lib ; ln -sf libgssapi.so.2.0.0 libgssapi.so.2 )
+( cd usr/heimdal/lib ; rm -rf libgssapi.so )
+( cd usr/heimdal/lib ; ln -sf libgssapi.so.2.0.0 libgssapi.so )
+( cd usr/heimdal/lib ; rm -rf libhdb.so.9 )
+( cd usr/heimdal/lib ; ln -sf libhdb.so.9.2.0 libhdb.so.9 )
+( cd usr/heimdal/lib ; rm -rf libhdb.so )
+( cd usr/heimdal/lib ; ln -sf libhdb.so.9.2.0 libhdb.so )
+( cd usr/heimdal/lib ; rm -rf libkadm5srv.so.8 )
+( cd usr/heimdal/lib ; ln -sf libkadm5srv.so.8.0.1 libkadm5srv.so.8 )
+( cd usr/heimdal/lib ; rm -rf libkadm5srv.so )
+( cd usr/heimdal/lib ; ln -sf libkadm5srv.so.8.0.1 libkadm5srv.so )
+( cd usr/heimdal/lib ; rm -rf libkadm5clnt.so.7 )
+( cd usr/heimdal/lib ; ln -sf libkadm5clnt.so.7.0.1 libkadm5clnt.so.7 )
+( cd usr/heimdal/lib ; rm -rf libkadm5clnt.so )
+( cd usr/heimdal/lib ; ln -sf libkadm5clnt.so.7.0.1 libkadm5clnt.so )
+( cd usr/heimdal/lib ; rm -rf libotp.so.0 )
+( cd usr/heimdal/lib ; ln -sf libotp.so.0.1.5 libotp.so.0 )
+( cd usr/heimdal/lib ; rm -rf libotp.so )
+( cd usr/heimdal/lib ; ln -sf libotp.so.0.1.5 libotp.so )
+( cd usr/heimdal/lib ; rm -rf libkdc.so.2 )
+( cd usr/heimdal/lib ; ln -sf libkdc.so.2.0.0 libkdc.so.2 )
+( cd usr/heimdal/lib ; rm -rf libkdc.so )
+( cd usr/heimdal/lib ; ln -sf libkdc.so.2.0.0 libkdc.so )
+( cd usr/heimdal/lib ; rm -rf windc.so.0 )
+( cd usr/heimdal/lib ; ln -sf windc.so.0.0.0 windc.so.0 )
+( cd usr/heimdal/lib ; rm -rf windc.so )
+( cd usr/heimdal/lib ; ln -sf windc.so.0.0.0 windc.so )
 ( cd usr/heimdal/bin ; rm -rf kauth )
 ( cd usr/heimdal/bin ; ln -sf kinit kauth )
